Source - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Source

`betty.model.ancestry.Source` entities describe where the information in an ancestry comes from, such as archives, correspondence, or personal accounts.

## Fields

Sources inherit from:

- Privacy

`author` (`str`)

  The human-readable name of the source’s author.

`citations` (iterable of Citation)

  The citations referencing the source.

`contained_by` (optional `Source`)

  Another source that contains this one.

`contains` (iterable of `Source`)

  Other sources contained by this one.

`date` (Datey)

  The source (access) date.

`files` (iterable of File)

  The files attached to this source.

`id` (`str`)

  The source’s own entity ID.

`links` (iterable of Link)

  The external links for this source.

`name` (`str`)

  The human-readable name.

`publisher` (`str`)

  The human-readable name of the source’s publisher.